@@ -704,9 +704,10 @@ class Env(BaseEnv):
 
         return ret
 
-    def get_env(self, directory: Union[Path, str]) -> "Env":
+    def get_env(self, directory: Union[Path, str], stage: Optional[str] = None) -> "Env":
+        stage = stage or self.meta.stage
         directory = Path(directory)
-        env_file = directory / f"env_{self.meta.stage}.py"
+        env_file = directory / f"env_{stage}.py"
 
         if not env_file.exists():
             logger.traceback()
@@ -716,9 +717,8 @@ class Env(BaseEnv):
         return env
 
     @classmethod
-    def get_env_path(cls, stage: Optional[str] = None) -> Path:
-        stage = stage or cls.Meta.stage
-        return cls.Meta.root / f"env_{stage}.py"
+    def get_env_path(cls) -> Path:
+        return cls.Meta.root / f"env_{cls.Meta.stage}.py"
 
     def _collect_magic_functions(self) -> None:
         """
